package com.simuwang.manage.api.system;

import com.simuwang.base.common.support.MybatisPage;
import com.simuwang.base.pojo.dto.command.DeleteByIdCmd;
import com.simuwang.base.pojo.dto.command.UpdateStatusCmd;
import com.simuwang.base.pojo.dto.query.UserPageQuery;
import com.simuwang.base.pojo.vo.SysUserVO;
import com.simuwang.base.pojo.vo.SysRoleUserVO;
import com.simuwang.manage.service.system.SysUserService;
import org.springframework.web.bind.annotation.*;

/**
 * @author wangzaijun
 * @date 2024/9/13 13:37
 * @description 用户管理相关接口
 */
@RestController
@RequestMapping("/v1/sys/user")
public class SysUserController {
    private final SysUserService service;

    public SysUserController(SysUserService service) {
        this.service = service;
    }

    /**
     * 分页接口
     *
     * @param query 用户列表分页请求参数
     * @return /
     */
    @GetMapping("page")
    public MybatisPage<SysUserVO> page(UserPageQuery query) {
        return this.service.findPage(query);
    }

    /**
     * 分页接口
     *
     * @param query 用户列表分页请求参数
     * @return /
     */
    @GetMapping("multi-join-page")
    public MybatisPage<SysRoleUserVO> multiJoinPage(UserPageQuery query) {
        return this.service.findMultiPage(query);
    }

    /**
     * 更新用户状态接口
     *
     * @param command 用户id+状态对象
     */
    @PostMapping("update-status")
    public void updateStatus(@RequestBody UpdateStatusCmd command) {
        this.service.updateStatus(command);
    }

    /**
     * 根据id删除用户信息接口
     *
     * @param command 用户id对象
     */
    @PostMapping("del")
    public void deleteById(@RequestBody DeleteByIdCmd command) {
        this.service.delete(command);
    }
}
