package com.simuwang.manage.service.impl.system;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.simuwang.base.common.support.*;
import com.simuwang.base.mapper.SysUserMapper;
import com.simuwang.base.pojo.dos.SysRoleUserDO;
import com.simuwang.base.pojo.dos.SysUserDO;
import com.simuwang.base.pojo.dto.query.RoleUserPageQuery;
import com.simuwang.base.pojo.dto.query.UserPageQuery;
import com.simuwang.base.pojo.vo.SysRoleUserVO;
import com.simuwang.base.pojo.vo.SysUserVO;
import com.simuwang.manage.service.system.SysUserService;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.stream.Collectors;

@Service
public class SysUserServiceImpl implements SysUserService {
    private final SysUserMapper mapper;

    public SysUserServiceImpl(SysUserMapper mapper) {
        this.mapper = mapper;
    }

    @Override
    public String[] selectColumns() {
        return BaseService.extColumns(DEFAULT_SELECT_COLUMNS,
                "user_id", "user_name", "email", "phonenumber", "sex", "avatar", "status");
    }

    @Override
    public <Q extends PageQuery> void wrapQuery(QueryWrapper<SysUserDO> wrapper, Q query) {
        UserPageQuery params = (UserPageQuery) query;
        String keyword = params.getKeyword();
        if (StrUtil.isNotBlank(keyword)) {
            wrapper.like("user_name", keyword)
                    .or()
                    .like("email", keyword)
                    .or()
                    .like("phonenumber", keyword);
        }
    }

    @Override
    public MybatisPage<SysUserVO> convertPage(Page<SysUserDO> page, QueryWrapper<SysUserDO> wrapper) {
        IPage<SysUserDO> entityPage = this.mapper.selectPage(page, wrapper);
        return MybatisPage.ofList(entityPage, SysUserDO::toVo);
    }

    @Override
    public <Q extends PageQuery> MybatisPage<SysRoleUserVO> findMultiPage(Q query) {
        RoleUserPageQuery params = (RoleUserPageQuery) query;
        List<SysRoleUserDO> dataList = this.mapper.roleUserPage(params);
        List<SysRoleUserVO> records = dataList.stream().map(SysRoleUserDO::toVo).collect(Collectors.toList());
        long count = this.mapper.countRoleUser(params);
        return MybatisPage.of(count, records);
    }

    @Override
    public <BSC extends BaseIdStatusCmd> void updateStatus(BSC command) {
        SysUserDO user = new SysUserDO();
        user.setUserId(command.getId());
        user.setStatus(command.getStatus());
        this.mapper.updateById(user);
    }

    @Override
    public <BIC extends BaseIdCmd> void delete(BIC command) {
        Integer id = command.getId();
        this.mapper.deleteById(id);
    }
}
